/**********************************************************
 ***  Header-Datei zur vorlufigen PCI1389S01-DLL       ***
 **********************************************************
 ***  Die Funktionen sollten sich nicht gegenber der   ***
 ***  endgltigen Version mit WIN9X-Treiber unter-      ***
 ***  scheiden.                                         ***
 **********************************************************
 ***       (c) 1999 by ERMA - Electronic GmbH           ***
 **********************************************************
 ***  Erstellt: 26.05.1999 Frank Jessen Dipl.Ing.(FH)   ***
 **********************************************************/
#ifndef _PCI1389S01_
#define _PCI1389S01_

/**********************************************************
 ***  Fehlermeldungen                                   ***
 **********************************************************/
#define PCI1389S01_ERR_OK          0
#define PCI1389S01_ERR_ALREADYOPEN 1
#define PCI1389S01_ERR_NOTOPEN     2
#define PCI1389S01_ERR_NOCARD      3
#define PCI1389S01_ERR_NOADDRESS   4
#define PCI1389S01_ERR_NOVALUE     5
#define PCI1389S01_ERR_WRONGMODE   6


/**********************************************************
 ***  Verwendete Typen                                  ***
 **********************************************************/
/*** Betriebsart ***/
struct _PCI1389S01_MODE
{
	unsigned short Cnt1_Mode;
	unsigned short Cnt2_Mode;
	unsigned short Ref_Mode;
	unsigned short Ref_Wert;
	unsigned short Io_Mode;
};

/*** Timeouts ***/
struct _PCI1389S01_TO
{
	unsigned long Cnt1;        // Wert Zhler 1 Timeout
	unsigned long Cnt2;        // Wert Zhler 2 Timeout
	unsigned long Ref;         // Wert Referenzzhler-Timeout
	unsigned char Cnt1En;      // Freigabe fr Zhler 1 Timeout
	unsigned char Cnt2En;      // Freigabe fr Zhler 2 Timeout
	unsigned char RefEn;       // Freigabe fr Referenzzhler Timeout
};

/*** Status ***/
struct _PCI1389S01_STAT
{
	unsigned short Cnt1;
	unsigned short Cnt2;
	unsigned short Ref;
};

/**********************************************************
 ***  Betriebsarten                                     ***
 **********************************************************/
#define PCI1389S01_INK1FACH    0x0001		// Z1,Z2,Ref
#define PCI1389S01_INK2FACH    0x0002		// Z1,Z2,Ref
#define PCI1389S01_INK4FACH    0x0004		// Z1,Z2,Ref
#define PCI1389S01_EREIGNIS    0x0008		// Z1,Z2,Ref
#define PCI1389S01_SWTRIG      0x0010		// Z1,Z2
#define PCI1389S01_REFTRIG     0x0020		// Z1,Z2
#define PCI1389S01_IOTRIG      0x0040		// Z1,Z2
#define PCI1389S01_INKREMENTAL 0x0080		// Z1,Z2,Ref
#define PCI1389S01_TIMER       0x0100   // Ref
#define PCI1389S01_TIMER5MHZ   0x0200		// Z1,Z2
#define PCI1389S01_TIMER10MHZ  0x0400		// Z1,Z2
#define PCI1389S01_RICHTUNG    0x0800		// Z1,Z2,Ref
#define PCI1389S01_POLARITAET  0x1000		// Z1,Z2,Ref
#define PCI1389S01_RESET       0x2000		// Z1,Z2
#define PCI1389S01_SIOTRIG     0x4000   // IO
#define PCI1389S01_FIOTRIG     0x8000   // IO

/**********************************************************
 ***  Statusflags                                       ***
 **********************************************************/
#define PCI1389S01_CNTSTOP     0x0001		// Z1,Z2,Ref
#define PCI1389S01_CNTWAIT     0x0002		// Z1,Z2,Ref
#define PCI1389S01_CNTRUN      0x0004		// Z1,Z2,Ref
#define PCI1389S01_CNTTIMEOUT  0x0008		// Z1,Z2,Ref
#define PCI1389S01_CNTINERR    0x0010		// Z1,Z2,Ref
#define PCI1389S01_CNTFIFOOV   0x0020		// Z1,Z2

/**********************************************************
 ***  Flags fr Zhlerauswahl                           ***
 **********************************************************/
#define PCI1389S01_CNT1				 0x01			// Z1
#define PCI1389S01_CNT2        0x02			// Z2
#define PCI1389S01_REF         0x04     // Ref

/**********************************************************
 ***  Funktionen                                        ***
 **********************************************************/
extern "C"
{
/*** Allgemeine Funktionen ***/
__declspec (dllimport) char __stdcall PCI1389S01_InitDriver    (void);
__declspec (dllimport) char __stdcall PCI1389S01_DeInitDriver  (void);
__declspec (dllimport) char __stdcall PCI1389S01_GetCardCount  (unsigned char  *Anzahl);

/*** Konfigurationsfunktionen ***/
__declspec (dllimport) char __stdcall PCI1389S01_SetMode       (unsigned char Card, struct _PCI1389S01_MODE *Mode);
__declspec (dllimport) char __stdcall PCI1389S01_GetMode       (unsigned char Card, struct _PCI1389S01_MODE *Mode);
__declspec (dllimport) char __stdcall PCI1389S01_SetTimeOuts   (unsigned char Card, struct _PCI1389S01_TO   *TimeOuts);
__declspec (dllimport) char __stdcall PCI1389S01_GetTimeOuts   (unsigned char Card, struct _PCI1389S01_TO   *TimeOuts);

/*** Mefunktionen ***/
__declspec (dllimport) char __stdcall PCI1389S01_StartCounter  (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S01_StopCounter   (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S01_GetStatus     (unsigned char Card, struct _PCI1389S01_STAT *Status);
__declspec (dllimport) char __stdcall PCI1389S01_GetCNT1Values (unsigned char Card, long (*buffer)[], unsigned long buffersize, unsigned long *n);
__declspec (dllimport) char __stdcall PCI1389S01_GetCNT2Values (unsigned char Card, long (*buffer)[], unsigned long buffersize, unsigned long *n);
__declspec (dllimport) char __stdcall PCI1389S01_LatchCounter  (unsigned char Card, unsigned char Flags);
__declspec (dllimport) char __stdcall PCI1389S01_SetPorts      (unsigned char Card, unsigned char Flags);
__declspec (dllimport) char __stdcall PCI1389S01_GetPorts      (unsigned char Card, unsigned char *Flags);

/*** Fehlerfunktion ***/
__declspec (dllimport) int  __stdcall PCI1389S01_GetLastError  (unsigned char Card);

/*** Low-Level Funktionen ***/
/*** HINWEIS: Fr diese Funktionen gelten nicht ***/
/*** die oben definierten Werte, sondern der    ***/
/*** Bitplan aus der Programmieranleitung !!!   ***/
/*** Werden diese Funktionen benutzt, so werden ***/
/*** die obigen Funktionen ausgehebelt! Diese   ***/
/*** Funktionen greifen direkt auf die Hardware ***/
/*** zu. Die Softwarefifos knnen nicht mehr    ***/
/*** richtig funktionieren! Daher sollten       ***/
/*** entweder die obigen Funktionen oder die    ***/
/*** Low-Level-Funktionen benutzt werden. Das   ***/
/*** mischen der Funktionsgruppen fhrt zu      ***/
/*** Fehlern bei den Mefunktionen!             ***/
__declspec (dllimport) char __stdcall PCI1389S01_WriteCNT1     (unsigned char Card, unsigned long   Wert);
__declspec (dllimport) char __stdcall PCI1389S01_ReadCNT1      (unsigned char Card, unsigned long  *Wert);
__declspec (dllimport) char __stdcall PCI1389S01_WriteCNT2     (unsigned char Card, unsigned long   Wert);
__declspec (dllimport) char __stdcall PCI1389S01_ReadCNT2      (unsigned char Card, unsigned long  *Wert);
__declspec (dllimport) char __stdcall PCI1389S01_WriteMode     (unsigned char Card, unsigned long   Mode);
__declspec (dllimport) char __stdcall PCI1389S01_ReadMode      (unsigned char Card, unsigned long  *Mode);
__declspec (dllimport) char __stdcall PCI1389S01_ReadStatus    (unsigned char Card, unsigned long  *Status);
__declspec (dllimport) char __stdcall PCI1389S01_Latch         (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S01_WriteIntEn    (unsigned char Card, unsigned long   IEN);
__declspec (dllimport) char __stdcall PCI1389S01_ReadIntEn     (unsigned char Card, unsigned long  *IEN);
__declspec (dllimport) char __stdcall PCI1389S01_ReadIntStat   (unsigned char Card, unsigned long  *IStat);
__declspec (dllimport) char __stdcall PCI1389S01_WriteRef      (unsigned char Card, unsigned short  Wert);
__declspec (dllimport) char __stdcall PCI1389S01_ReadRef       (unsigned char Card, unsigned short *Wert);
__declspec (dllimport) char __stdcall PCI1389S01_WriteIO       (unsigned char Card, unsigned char   Wert);
__declspec (dllimport) char __stdcall PCI1389S01_ReadIO        (unsigned char Card, unsigned char  *Wert);
}

#endif